colour.quality Package — Colour 0.3.0 documentation

# colour.quality Package

## Sub-Packages

- colour.quality.dataset Package
  - Sub-Modules
    - colour.quality.dataset.tcs Module
      - Test Colour Samples Spectral Power Distributions
  - Module Contents

## Sub-Modules

- colour.quality.cri Module
  - Colour Rendering Index

## Module Contents

`colour.quality.` `colour_rendering_index`(test_spd, additional_data=False)

  Returns the colour rendering index of given spectral power distribution.

  Parameters: | test_spd (SpectralPowerDistribution) – Test spectral power distribution. additional_data (bool, optional) – Output additional data.
  Returns: | Colour rendering index, Tsc data.
  Return type: | numeric or (numeric, dict)

  Examples

      >>> from colour import ILLUMINANTS_RELATIVE_SPDS
      >>> spd = ILLUMINANTS_RELATIVE_SPDS.get('F2')
      >>> colour_rendering_index(spd)
      64.1507331...